@@ -163,6 +163,24 @@ class TestHDFWriterPart(ChildTestCase):
             "fileTemplate",
         ]
 
+    @patch("malcolm.modules.ADCore.parts.hdfwriterpart.check_driver_version")
+    def test_validate(self, check_mock):
+        self.o = HDFWriterPart(name="m", mri="BLOCK:HDF5")
+
+        # Version check should not be called with require_version None
+        self.o.require_version = None
+        self.set_attributes(self.child, driverVersion="1.1")
+
+        self.o.on_validate(self.context)
+
+        check_mock.assert_not_called()
+
+        # Test version check called if required_version not None
+        self.o.required_version = "1.0"
+        self.o.on_validate(self.context)
+
+        check_mock.assert_called_once_with("1.1", "1.0")
+
     def configure_and_check_output(self, on_windows=False):
         energy = LineGenerator("energy", "kEv", 13.0, 15.2, 2)
         spiral = SpiralGenerator(["x", "y"], ["mm", "mm"], [0.0, 0.0], 5.0, scale=2.0)
@@ -211,28 +229,28 @@ class TestHDFWriterPart(ChildTestCase):
         assert infos[1].name == "xspress3.sum"
         assert infos[1].filename == "thing-xspress3.h5"
         assert infos[1].type == DatasetType.SECONDARY
-        assert infos[1].rank == 4
+        assert infos[1].rank == 2
         assert infos[1].path == "/entry/sum/sum"
         assert infos[1].uniqueid == "/entry/NDAttributes/NDArrayUniqueId"
 
         assert infos[2].name == "I0.data"
         assert infos[2].filename == "thing-xspress3.h5"
         assert infos[2].type == DatasetType.PRIMARY
-        assert infos[2].rank == 4
+        assert infos[2].rank == 2
         assert infos[2].path == "/entry/I0.data/I0.data"
         assert infos[2].uniqueid == "/entry/NDAttributes/NDArrayUniqueId"
 
         assert infos[3].name == "It.data"
         assert infos[3].filename == "thing-xspress3.h5"
         assert infos[3].type == DatasetType.MONITOR
-        assert infos[3].rank == 4
+        assert infos[3].rank == 2
         assert infos[3].path == "/entry/It.data/It.data"
         assert infos[3].uniqueid == "/entry/NDAttributes/NDArrayUniqueId"
 
         assert infos[4].name == "t1x.value"
         assert infos[4].filename == "thing-xspress3.h5"
         assert infos[4].type == DatasetType.POSITION_VALUE
-        assert infos[4].rank == 4
+        assert infos[4].rank == 2
         assert infos[4].path == "/entry/t1x.value/t1x.value"
         assert infos[4].uniqueid == "/entry/NDAttributes/NDArrayUniqueId"
 
